#
# spec file for package rbenv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rbenv
Version:        1.3.2
Release:        1.3
BuildArch:      noarch
License:        MIT
Group:          Development/Languages/Ruby
URL:            https://github.com/rbenv/rbenv
Summary:        Simple Ruby version Management
Source0:        https://github.com/rbenv/rbenv/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
%if %{undefined sle_version}
BuildRequires:  bats
BuildRequires:  git
BuildRequires:  procps
%endif
Requires:       procps
Recommends:     ruby-build

%description
rbenv does…

- Let you change the global Ruby version on a per-user basis.
- Provide support for per-project Ruby versions.
- Allow you to override the Ruby version with an environment variable.

In contrast with rvm, rbenv does not…

- Need to be loaded into your shell. Instead, rbenv's shim approach works by adding a directory to your $PATH.
- Override shell commands like cd. That's dangerous and error-prone.
- Have a configuration file. There's nothing to configure except which version of Ruby you want to use.
- Install Ruby. You can build and install Ruby yourself, or use ruby-build to automate the process.
- Manage gemsets. Bundler is a better way to manage application dependencies. If you have projects that are not yet using Bundler you can install the rbenv-gemset plugin.
- Require changes to Ruby libraries for compatibility. The simplicity of rbenv means as long as it's in your $PATH, nothing else needs to know about it.
- Prompt you with warnings when you switch to a project. Instead of executing arbitrary code, rbenv reads just the version name from each project. There's nothing to "trust."

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
The official bash completion script for %{name}.

%package zsh-completion
Summary:        ZSH completion for %{name}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for %{name}.

%prep
%setup -q

%build

%install
install -Dm0755 libexec/* -t %{buildroot}%{_bindir}

install -Dm0644 completions/rbenv.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm0644 completions/_rbenv %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -Dm0644 share/man/man1/rbenv.1 %{buildroot}%{_mandir}/man1/%{name}.1

mkdir -p %{buildroot}/usr/lib/rbenv
cp -r rbenv.d/* %{buildroot}/usr/lib/rbenv

sed -i 's|#!/usr/bin/env bash|#!/bin/bash|g' %{buildroot}%{_bindir}/*

%check
%if %{undefined sle_version}
bats test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/rbenv*
/usr/lib/rbenv
%{_mandir}/man1/%{name}*

%files bash-completion
%{_datadir}/bash-completion

%files zsh-completion
%{_datadir}/zsh

%changelog
* Wed Jan  8 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 1.3.2.
  Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.3.2
  * Fix traversing PATH for bash < 4.4 by @mislav in #1606
* Wed Jan  8 2025 Lukas Müller <expeehaa@outlook.com>
- Update to version 1.3.1.
  Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.3.1
  * Add `/usr/etc/rbenv.d` to hooks path by @tomschr in #1587
  * Use `readarray` in bash v4+ to avoid rbenv init hanging by @mislav in #1604
  * Add instructions for Fedora Linux installation by @nethad in #1583
  * Skip BW01 and BW02 error messages during tests by @mikelolasagasti in #1600
  * Bump mislav/bump-homebrew-formula-action from 3.1 to 3.2 by @dependabot in #1598
* Sat Jul  6 2024 Lukas Müller <expeehaa@outlook.com>
- Update to version 1.3.0.
  Full changelog: https://github.com/rbenv/rbenv/releases/tag/v1.3.0
  * The `rbenv init` command now modifies shell initialization files instead of printing instructions by @mislav in #1568
    This solves one of the most common pitfalls rbenv users were experiencing: many did not understand that `rbenv init` only printed instructions intended for humans but did not change anything in their shell environment. Now, `rbenv init` actually modifies the environment, which seems to be what most users expected in the first place.
  * rbenv init in setup mode defaults to no auto-rehashing by @mislav in #1579
  * Init script automatically adds rbenv to PATH if necessary by @mislav in #1432
  * Simplify resolving symlinks, remove native bash extension by @mislav in #1428
    This solves a GPL license compliance issue where a GPL-licensed script was distributed with this project, which was not compatible with this project's license (MIT). https://github.com/rbenv/rbenv/issues/1395
  * Support GEM_HOME by @mislav in #1436
  * Add man page for rbenv by @mislav in #1438
    Preview the man page in HTML form here: https://rbenv.org/man/rbenv.1
  * Simplify `.ruby-version` file read by @scop in #1393
  * Ignore shell builtins and functions when looking up commands in PATH by @mislav in #1448
  * Use the newer “compsys” completion system for zsh completions by @Farid-NL in #1569
  * Ensure zsh user's prior shell options don't interfere with indexing into an array of arguments by @richiethomas in #1422
  * rbenv shell: properly declare global variables for zsh by @mislav in #1566
  * Support ksh versions by @kpschoedel in #1504
* Tue May 24 2022 Lukas Müller <expeehaa@outlook.com>
- Run "osc service runall format_spec_file".
* Mon May 23 2022 Lukas Müller <expeehaa@outlook.com>
- Remove unnecessary conflict with a potential rvm package.
* Mon May 23 2022 Lukas Müller <expeehaa@outlook.com>
- Re-enable skipped tests by requiring the procps package.
- Use /usr/lib/rbenv instead of /etc/rbenv.d for hooks.
- Factor bash and zsh completions out into subpackages.
- Add %%changelog macro at the end of the spec file.
- Remove _service file.
- Remove broken completion path fix without replacement.
* Wed Nov 10 2021 Lukas Müller <expeehaa@outlook.com>
- Fix completion installation.
- Install hooks.
* Fri Nov  5 2021 Müller <expeehaa@outlook.com>
- Enable tests on openSUSE in %%check step.
* Fri Nov  5 2021 Lukas Müller <expeehaa@outlook.com>
- Update to 1.2.0
- Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.2.0
* Sun Oct  4 2020 Michele Bologna <Michele.Bologna@suse.com>
- Update to 1.1.2
- Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.1.2
* Fri Feb  9 2018 michele.bologna@suse.com
- Update to 1.1.1
- Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.1.1
* Tue Mar 14 2017 mamorales@suse.com
- update to 1.1.0
- see https://github.com/rbenv/rbenv/releases/tag/v1.1.0
* Wed Dec 30 2015 dmacvicar@suse.de
- update to 1.0.0
- see https://github.com/rbenv/rbenv/releases/tag/v1.0.0
* Fri Oct 18 2013 dmacvicar@suse.de
- update to 0.4.0
* Wed Jan  4 2012 dmacvicar@suse.de
- update to 0.3.0
* Wed Jan  4 2012 dmacvicar@suse.de
- add BuildRoot tag
* Thu Dec  8 2011 dmacvicar@suse.de
- sync with git master
* Thu Nov 24 2011 dmacvicar@suse.de
- Move completions to /usr/share/rbenv/completions
- remove patch for completions and just modify rbenv-init
  to ouput the right path.
* Wed Nov 16 2011 dmacvicar@suse.de
- patch rbenv-init to not source completions as we install them
  in completions.d
* Wed Nov 16 2011 dmacvicar@suse.de
- initial package for 0.2.1
